@@ -235,17 +235,34 @@ sub method_name_conflicts
 
 sub auto_foreign_key_name
 {
-  my($self, $f_class, $current_name) = @_;
+  my($self, $f_class, $current_name, $key_columns, $used_names) = @_;
   my $f_meta = $f_class->meta or return $current_name;
   my $name = $self->plural_to_singular($f_meta->table) || $current_name;
 
+  if(keys %$key_columns == 1)
+  {
+    my($local_column, $foreign_column) = %$key_columns;
+
+    # Try to lop off foreign column name.  Example:
+    # my_foreign_object_id -> my_foreign_object
+    if($local_column =~ s/_$foreign_column$//)
+    {
+      $name = $local_column;
+    }
+    else
+    {
+      $name = $self->plural_to_singular($f_meta->table) || $current_name;
+    }
+  }
+
   # Avoid method name conflicts
-  if($self->method_name_conflicts($name))
+  if($self->method_name_conflicts($name) || $used_names->{$name})
   {
     foreach my $s ('_obj', '_object')
     {
       # Try the name with a suffix appended
-      unless($self->method_name_conflicts($name . $s))
+      unless($self->method_name_conflicts($name . $s) ||
+             $used_names->{$name . $s})
       {
         return $name . $s;
       }
@@ -253,7 +270,8 @@ sub auto_foreign_key_name
       my $i = 1;
 
       # Give up and go with numbers...
-      $i++  while($self->method_name_conflicts($name . $i));
+      $i++  while($self->method_name_conflicts($name . $i) ||
+                  $used_names->{$name . $i});
 
       return $name . $i;
     }
@@ -890,13 +908,31 @@ Consider column maps in this order:
     { vendor => 'id' }      { NAME => FPK }
     { vendor_id => 'id' }   { <NAME>_<FPK> => FPK }
 
-=item B<auto_foreign_key_name FOREIGN_CLASS [, CURRENT_NAME]>
+=item B<auto_foreign_key_name FOREIGN_CLASS, CURRENT_NAME, KEY_COLUMNS, USED_NAMES>
 
-Given the name of a foreign class and an optional pre-existing foreign key name, return a L<name|Rose::DB::Object::Metadata::ForeignKey/name>  for the foreign key.
+Given the name of a foreign class, the current foreign key name (if any), a reference to a hash of L<key columns|Rose::DB::Object::Metadata::ForeignKey/key_columns>, and a reference to a hash whose keys are foreign key names already used in this class, return a L<name|Rose::DB::Object::Metadata::ForeignKey/name> for the foreign key.
 
-Calls L<plural_to_singular|/plural_to_singular>, passing the L<table|Rose::DB::Object::Metadata/table> name of the foreign class.  The current name is used if the call to L<plural_to_singular|/plural_to_singular> does not return a true value.
+If there is more than one pair of columns in KEY_COLUMNS, then the name is generated by calling L<plural_to_singular|/plural_to_singular>, passing the L<table|Rose::DB::Object::Metadata/table> name of the foreign class.  The CURRENT_NAME is used if the call to L<plural_to_singular|/plural_to_singular> does not return a true value.
 
-If the selected name is the name of an existing or potential method in the target class, then the suffixes "obj_" and "_object" are tried in that order.  If neither of those suffixes resolves the situation, then ascending numeric suffixes starting with "1" are tried until a unique name is found.
+If there is just one pair of columns in KEY_COLUMNS, and if the name of the local column ends with an underscore and the name of the referenced column, then that part of the column name is removed and the remaining string is used as the foreign key name.  For example, given the following tables:
+
+    CREATE TABLE categories
+    (
+      id  SERIAL PRIMARY KEY,
+      ...
+    );
+
+    CREATE TABLE products
+    (
+      category_id  INT REFERENCES categories (id),
+      ...
+    );
+
+The foreign key name would be "category", which is the name of the referring column ("category_id") with an underscore and the name of the referenced column ("_id") removed from the end of it.
+
+If the foreign key has only one column, but it does not meet the criteria described above, then the name is generated by calling L<plural_to_singular|/plural_to_singular>, passing the L<table|Rose::DB::Object::Metadata/table> name of the foreign class.  The CURRENT_NAME is used if the call to L<plural_to_singular|/plural_to_singular> does not return a true value.
+
+If the name selected using the above techniques is in the USED_NAMES hash, or is the same as that of an existing or potential method in the target class, then the suffixes "_obj" and "_object" are tried in that order.  If neither of those suffixes resolves the situation, then ascending numeric suffixes starting with "1" are tried until a unique name is found.
 
 =item B<auto_manager_base_name TABLE, CLASS>
 
@@ -1505,6 +1541,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
