@@ -17,9 +17,9 @@ sub type { 'boolean' }
 sub parse_value  { shift; shift->parse_boolean(@_)  }
 sub format_value { shift; shift->format_boolean(@_) }
 
-sub perl_column_defintion_attributes
+sub perl_column_definition_attributes
 {
-  grep { $_ ne 'length' } shift->SUPER::perl_column_defintion_attributes;
+  grep { $_ ne 'length' } shift->SUPER::perl_column_definition_attributes;
 }
 
 sub method_uses_formatted_key
@@ -91,6 +91,6 @@ John C. Siracusa (siracusa@mindspring.com)
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 by John C. Siracusa.  All rights reserved.  This program is
+Copyright (c) 2007 by John C. Siracusa.  All rights reserved.  This program is
 free software; you can redistribute it and/or modify it under the same terms
 as Perl itself.
