@@ -3,13 +3,16 @@ package Rose::DB::Object::Metadata::ForeignKey;
 use strict;
 
 use Carp();
+use Scalar::Util();
 
 use Rose::DB::Object::Metadata::Util qw(:all);
 
 use Rose::DB::Object::Metadata::Column;
 our @ISA = qw(Rose::DB::Object::Metadata::Column);
 
-our $VERSION = '0.756';
+use Rose::DB::Object::Exception;
+
+our $VERSION = '0.764';
 
 our $Debug = 0;
 
@@ -34,6 +37,8 @@ use Rose::Object::MakeMethods::Generic
   [
     'share_db' => { default => 1 },
     'referential_integrity' => { default => 1 },
+    'with_column_triggers' => { default => 0 },
+    'disable_column_triggers',
   ],
 
   scalar => 'deferred_make_method_args',
@@ -174,6 +179,41 @@ sub make_methods
   my($self) = shift;
   $self->is_required; # initialize
   $self->SUPER::make_methods(@_);
+
+  if($self->with_column_triggers)
+  {
+    my $method = $self->method_name('get_set_on_save') ||
+                 $self->method_name('get_set');
+
+    if($method)
+    {
+      my $meta = $self->parent or 
+        Carp::croak "Missing parent for foreign key '", $self->name, "'";
+
+      my $key_columns = $self->key_columns;
+
+      foreach my $column_name (keys %$key_columns)
+      {
+        Scalar::Util::weaken(my $column = $meta->column($column_name));
+        my $accessor     = $column->accessor_method_name;
+        my $trigger_name = 'clear_fk' . $self->name;
+
+        unless(defined $column->builtin_trigger_index('on_set', $trigger_name))
+        {
+          $column->add_builtin_trigger(
+            event => 'on_set',
+            name  => $trigger_name,
+            code  => sub 
+            {
+              my($obj) = shift;
+              return  if($self->{'disable_column_triggers'});
+              local $column->{'triggers_disabled'} = 1;
+              $obj->$method(undef)  unless(defined $obj->$accessor());
+            });
+        }
+      }
+    }
+  }
 }
 
 sub build_method_name_for_type
@@ -228,8 +268,9 @@ sub is_ready_to_make_methods
 
   eval
   {
-    $self->class->isa('Rose::DB::Object') 
-      or die "Missing or invalid foreign class";
+    $self->class->isa('Rose::DB::Object') or die
+      Rose::DB::Object::Exception::ClassNotReady->new(
+        "Missing or invalid foreign class");
 
     my $fk_meta = $self->class->meta;
 
@@ -239,13 +280,15 @@ sub is_ready_to_make_methods
     {
       unless($fk_meta->column($column_name))
       {
-        die "No column '$column_name' in class ", $fk_meta->class;
+        die Rose::DB::Object::Exception::ClassNotReady->new(
+              "No column '$column_name' in class " . $fk_meta->class);
       }
 
       unless($fk_meta->column_accessor_method_name($column_name) && 
              $fk_meta->column_mutator_method_name($column_name))
       {
-        die "Foreign class not initialized";
+        die Rose::DB::Object::Exception::ClassNotReady->new(
+              "Foreign class not initialized");
       }
     }
   };
@@ -529,7 +572,7 @@ Get or set a hash that maps local column names to foreign column names in the ta
 
 =item B<make_methods PARAMS>
 
-Create object method used to manipulate object referenced by the foreign key.  PARAMS are name/value pairs.  Valid PARAMS are:
+Create object method used to manipulate object referenced by the foreign key.  Any applicable L<column triggers|/with_column_triggers> are also added.  PARAMS are name/value pairs.  Valid PARAMS are:
 
 =over 4
 
@@ -593,6 +636,10 @@ This method is the mirror image of the L<referential_integrity|/referential_inte
 
 Returns "foreign key".
 
+=item B<with_column_triggers [BOOL]>
+
+Get or set a boolean value that indicates whether or not L<triggers|Rose::DB::Object::Metadata::Column/TRIGGERS> should be added to the L<key columns|/key_columns> in an attempt to keep foreign objects and foreign key columns in sync.  Defaults to false.
+
 =back
 
 =head1 PROTECTED API
