@@ -8,6 +8,7 @@ use Scalar::Util qw(weaken);
 use Rose::DB::Object::Metadata::Relationship;
 our @ISA = qw(Rose::DB::Object::Metadata::Relationship);
 
+use Rose::DB::Object::Exception;
 use Rose::Object::MakeMethods::Generic;
 use Rose::DB::Object::MakeMethods::Generic;
 
@@ -17,7 +18,7 @@ our $VERSION = '0.759';
 
 our $Debug = 0;
 
-__PACKAGE__->default_auto_method_types(qw(get_set_on_save add_on_save));
+__PACKAGE__->default_auto_method_types(qw(find get_set_on_save add_on_save));
 
 __PACKAGE__->add_common_method_maker_argument_names
 (
@@ -57,6 +58,20 @@ Rose::Object::MakeMethods::Generic->make_methods
 
 __PACKAGE__->method_maker_info
 (
+  count =>
+  {
+    class     => 'Rose::DB::Object::MakeMethods::Generic',
+    type      => 'objects_by_map',
+    interface => 'count',
+  },
+
+  find =>
+  {
+    class     => 'Rose::DB::Object::MakeMethods::Generic',
+    type      => 'objects_by_map',
+    interface => 'find',
+  },
+
   get_set =>
   {
     class => 'Rose::DB::Object::MakeMethods::Generic',
@@ -130,7 +145,7 @@ MAKE_MAP_RECORD_METHOD:
         return $weaken ? (weaken($self->{$key} = $arg)) : ($self->{$key} = $arg);
       }
 
-      return $self->{$key} ||= $map_class->new;
+      return $self->{$key}; # ||= $map_class->new;
     };
 
     $map_to_class->meta->map_record_method_key($map_record_method => $key);
@@ -169,6 +184,14 @@ sub build_method_name_for_type
   {
     return 'add_' . $self->name;
   }
+  elsif($type eq 'find')
+  {
+    return 'find_' . $self->name;
+  }
+  elsif($type eq 'count')
+  {
+    return $self->name . '_count';
+  }
 
   return undef;
 }
@@ -238,10 +261,11 @@ sub is_ready_to_make_methods
         {
           if(%map_column_to_self_method)
           {
-            Carp::croak "Map class $map_class has more than one foreign key ",
-                        "and/or 'many to one' relationship that points to the ",
-                        "class $target_class.  Please specify one by name ",
-                        "with a 'local' parameter in the 'map' hash";
+            die Rose::DB::Object::Exception::ClassNotReady->new(
+              "Map class $map_class has more than one foreign key " .
+              "and/or 'many to one' relationship that points to the " .
+              "class $target_class.  Please specify one by name " .
+              "with a 'local' parameter in the 'map' hash");
           }
 
           $map_from = $local_rel = $item->name;
@@ -253,8 +277,9 @@ sub is_ready_to_make_methods
           while(my($local_column, $foreign_column) = each(%$map_columns))
           {
             my $foreign_method = $meta->column_accessor_method_name($foreign_column)
-              or Carp::croak "Missing accessor method for column '$foreign_column'", 
-                             " in class ", $meta->class;
+              or die Rose::DB::Object::Exception::ClassNotReady->new(
+                   "Missing accessor method for column '$foreign_column'" .
+                   " in class " . $meta->class);
             $map_column_to_self_method{$local_column} = $foreign_method;
             $map_column_to_self_column{$local_column} = $foreign_column;
           }
@@ -274,10 +299,11 @@ sub is_ready_to_make_methods
 
         if($require_objects)
         {
-          Carp::croak "Map class $map_class has more than one foreign key ",
-                      "and/or 'many to one' relationship that points to a ",
-                      "class other than $target_class.  Please specify one ",
-                      "by name with a 'foreign' parameter in the 'map' hash";
+          die Rose::DB::Object::Exception::ClassNotReady->new(
+            "Map class $map_class has more than one foreign key " .
+            "and/or 'many to one' relationship that points to a " .
+            "class other than $target_class.  Please specify one " .
+            "by name with a 'foreign' parameter in the 'map' hash");
         }
 
         $map_to_class = $item->class;
@@ -290,12 +316,14 @@ sub is_ready_to_make_methods
         while(my($local_column, $foreign_column) = each(%$map_columns))
         {
           my $local_method = $map_meta->column_accessor_method_name($local_column)
-            or Carp::croak "Missing accessor method for column '$local_column'", 
-                           " in class ", $map_meta->class;
+            or die Rose::DB::Object::Exception::ClassNotReady->new(
+              "Missing accessor method for column '$local_column'" .
+              " in class " . $map_meta->class);
 
           my $foreign_method = $map_to_meta->column_accessor_method_name($foreign_column)
-            or Carp::croak "Missing accessor method for column '$foreign_column'", 
-                           " in class ", $map_to_meta->class;
+            or die Rose::DB::Object::Exception::ClassNotReady->new(
+              "Missing accessor method for column '$foreign_column'" .
+              " in class " . $map_to_meta->class);
 
           # local           foreign
           # Map:color_id => Color:id
@@ -308,21 +336,23 @@ sub is_ready_to_make_methods
         $map_to_method = $item->method_name('get_set') || 
                          $item->method_name('get_set_now') ||
                          $item->method_name('get_set_on_save') ||
-                         Carp::confess "No 'get_*' method found for ",
-                                       $item->name;
+                         die Rose::DB::Object::Exception::ClassNotReady->new(
+                           "No 'get_*' method found for " . $item->name);
       }
     }
 
     unless(%map_column_to_self_method)
     {
-      Carp::croak "Could not find a foreign key or 'many to one' relationship ",
-                  "in $map_class that points to $target_class";
+      die Rose::DB::Object::Exception::ClassNotReady->new(
+        "Could not find a foreign key or 'many to one' relationship "  .
+        "in $map_class that points to $target_class");
     }
 
     unless(%map_column_to_self_column)
     {
-      Carp::croak "Could not find a foreign key or 'many to one' relationship ",
-                  "in $map_class that points to ", ($map_to_class || $map_to);
+      die Rose::DB::Object::Exception::ClassNotReady->new(
+        "Could not find a foreign key or 'many to one' relationship " .
+        "in $map_class that points to " . ($map_to_class || $map_to));
     }
 
     unless($require_objects)
@@ -344,11 +374,12 @@ sub is_ready_to_make_methods
         {  
           if($require_objects)
           {
-            Carp::croak "Map class $map_class has more than two foreign keys ",
-                        "and/or 'many to one' relationships that points to a ",
-                        "$target_class.  Please specify which ones to use ",
-                        "by including 'local' and 'foreign' parameters in the ",
-                        "'map' hash";
+            die Rose::DB::Object::Exception::ClassNotReady->new(
+              "Map class $map_class has more than two foreign keys " .
+              "and/or 'many to one' relationships that points to a " .
+              "$target_class.  Please specify which ones to use " .
+              "by including 'local' and 'foreign' parameters in the " .
+              "'map' hash");
           }
 
           $require_objects = [ $item->name ];
@@ -356,24 +387,28 @@ sub is_ready_to_make_methods
           $map_to_method = $item->method_name('get_set') ||
                            $item->method_name('get_set_now') ||
                            $item->method_name('get_set_on_save') ||
-                           Carp::confess "No 'get_*' method found for ",
-                                         $item->name;
+                           die Rose::DB::Object::Exception::ClassNotReady->new(
+                             "No 'get_*' method found for " . $item->name);
         }
       }
     }
 
     unless($require_objects)
     {
-      Carp::croak "Could not find a foreign key or 'many to one' relationship ",
-                  "in $map_class that points to a class other than $target_class"
+      die Rose::DB::Object::Exception::ClassNotReady->new(
+        "Could not find a foreign key or 'many to one' relationship " .
+        "in $map_class that points to a class other than $target_class");
     }
 
-    die "Missing foreign class"  unless($foreign_class);
+    unless($foreign_class)
+    {
+      die Rose::DB::Object::Exception::ClassNotReady->new("Missing foreign class");
+    }
   };
 
   if($@ && ($Debug || $Rose::DB::Object::Metadata::Debug))
   {
-    my $err = $@;
+    my $err = "$@";
     $err =~ s/ at .*//;
     warn $self->parent->class, ': many-to-many relationship ', $self->name, " NOT READY - $err";
   }
@@ -566,6 +601,14 @@ Now the code:
 
 =over 4
 
+=item C<count>
+
+L<Rose::DB::Object::MakeMethods::Generic>, L<objects_by_key|Rose::DB::Object::MakeMethods::Generic/objects_by_map>, C<interface =E<gt> 'count'> ...
+
+=item C<find>
+
+L<Rose::DB::Object::MakeMethods::Generic>, L<objects_by_key|Rose::DB::Object::MakeMethods::Generic/objects_by_map>, C<interface =E<gt> 'find'> ...
+
 =item C<get_set>
 
 L<Rose::DB::Object::MakeMethods::Generic>, L<objects_by_map|Rose::DB::Object::MakeMethods::Generic/objects_by_map>, 
